@@ -1,37 +1,53 @@
 #!/usr/bin/python3
 
-import socket
+"""Launch PostgreSQL and MySQL database, then run tests."""
+
 import os
-import tempfile
 import shutil
-import subprocess
-import pytest
-import sys
 import signal
+import socket
+import subprocess
+import sys
+import tempfile
 import time
+from os.path import exists
+from os.path import join
+
 import psycopg2
-import MySQLdb
+import pytest
+
+test_mysql = False
+try:
+    import MySQLdb
 
 
-from os.path import join, exists
+except ModuleNotFoundError:
+    test_mysql = False
 
 lib_postgresql = "/usr/lib/postgresql/"
 
 
 class Postgres:
-    def __init__(self, host: str, port: int):
-        self.bin_dir = self.find_postgresql_bin()
+    """Postgres."""
 
-        if not self.bin_dir:
+    bin_dir: str
+    host: str
+    port: int
+
+    def __init__(self, host: str, port: int):
+        """Init."""
+        if not (bin_dir := self.find_postgresql_bin()):
             print("postgresql bin dir not found")
             sys.exit(1)
 
+        self.bin_dir = bin_dir
         self.host = host
         self.port = port
         self.base_dir = tempfile.mkdtemp()
         os.mkdir(join(self.base_dir, "tmp"))
 
-    def run_initdb(self):
+    def run_initdb(self) -> None:
+        """Run initdb."""
         print("running initdb")
         initdb = join(self.bin_dir, "bin", "initdb")
 
@@ -47,7 +63,8 @@ class Postgres:
         ]
         subprocess.run(args, check=True)
 
-    def run_server(self):
+    def run_server(self) -> subprocess.Popen[str]:
+        """Run server."""
         print("starting server")
         postgres = join(self.bin_dir, "bin", "postgres")
         assert os.path.exists(postgres)
@@ -66,9 +83,10 @@ class Postgres:
             "-c",
             "logging_collector=off",
         ]
-        return subprocess.Popen(args, stderr=subprocess.PIPE)
+        return subprocess.Popen(args, text=True, stderr=subprocess.PIPE)
 
-    def stop_server(self, server):
+    def stop_server(self, server: subprocess.Popen[str]) -> None:
+        """Stop server."""
         print("stopping postgres server")
         if server is None:
             return
@@ -81,7 +99,8 @@ class Postgres:
                 server.kill()
             time.sleep(0.1)
 
-    def configure(self):
+    def configure(self) -> None:
+        """Configure PostgreSQL."""
         conn_params = {"user": "postgres", "host": self.host, "port": self.port}
         for _ in range(50):
             try:
@@ -116,6 +135,7 @@ class Postgres:
         conn.close()
 
     def find_postgresql_bin(self) -> str | None:
+        """Find PostgreSQL bin."""
         versions = [int(d) for d in os.listdir(lib_postgresql) if d.isdigit()]
 
         for v in sorted(versions, reverse=True):
@@ -127,21 +147,30 @@ class Postgres:
 
 
 class MySQL:
+    """MySQL."""
+
+    base_dir: str
+    port: int
+    user: str = "root"
+    dbname: str = "test"
+
     def __init__(self, port: int):
+        """Init."""
         self.base_dir = tempfile.mkdtemp()
         self.port = port
-        self.user = "root"
-        self.dbname = "test"
 
     @property
-    def mysql_files(self):
+    def mysql_files(self) -> str:
+        """Location of mysql-files."""
         return os.path.join(self.base_dir, "mysql-files")
 
     @property
-    def socket_path(self):
+    def socket_path(self) -> str:
+        """Socket location."""
         return f"{self.base_dir}/mysql.sock"
 
-    def initalize(self):
+    def initalize(self) -> None:
+        """Run command to initialize MySQL ready for tests."""
         args = [
             "/usr/sbin/mysqld",
             "--initialize-insecure",
@@ -150,7 +179,8 @@ class MySQL:
         subprocess.run(args, stderr=None, check=True)
         os.mkdir(self.mysql_files)
 
-    def run_server(self):
+    def run_server(self) -> subprocess.Popen[str]:
+        """Run MySQL server."""
         args = [
             "/usr/bin/mysqld_safe",
             "--datadir=" + self.base_dir,
@@ -158,12 +188,13 @@ class MySQL:
             f"--secure-file-priv={self.mysql_files}",
             "--skip-networking",
         ]
-        return subprocess.Popen(args, stderr=subprocess.PIPE)
+        return subprocess.Popen(args, text=True, stderr=subprocess.PIPE)
 
-    def configure(self):
+    def configure(self) -> None:
+        """Configure."""
         for _ in range(50):
             try:
-                conn = MySQLdb.connect(user=self.user, unix_socket=self.socket_path)
+                conn = MySQLdb.connect(user=self.user, unix_socket=self.socket_path)  # type: ignore
             except MySQLdb._exceptions.OperationalError as e:
                 if e.args[0] != 2002:
                     raise
@@ -177,42 +208,45 @@ class MySQL:
         conn.close()
 
     @property
-    def url(self):
+    def url(self) -> str:
+        """URL."""
         return f"mysql://{self.user}@/{self.dbname}?unix_socket={self.socket_path}"
 
-    def stop_server(self):
+    def stop_server(self) -> None:
+        """Stop MySQL server."""
         print("stopping mysql server")
         args = ["mysqladmin", f"--socket={self.socket_path}", "-u", self.user, "shutdown"]
         subprocess.run(args, check=True)
 
+
 def get_unused_port(host: str) -> int:
     """Find and return an unused port."""
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.bind((host, 0))
-    port = sock.getsockname()[1]
+    port: int = sock.getsockname()[1]
     sock.close()
 
     return port
 
 
-def clean_up(base_dir):
+def clean_up(base_dir: str) -> None:
+    """Clean up."""
     print("clean up")
     shutil.rmtree(base_dir, ignore_errors=True)
 
 
-def main():
+def main() -> int:
     """Start scratch database server and run tests."""
-
-
     host = "localhost"
     pg_port = get_unused_port(host)
     mysql_port = get_unused_port(host)
 
-    mysql = MySQL(mysql_port)
-    mysql.initalize()
-    mysql_server = mysql.run_server()
-    os.environ["PYTEST_MYSQL_DB_URL"] = mysql.url
-    mysql.configure()
+    if test_mysql:
+        mysql = MySQL(mysql_port)
+        mysql.initalize()
+        mysql.run_server()
+        os.environ["PYTEST_MYSQL_DB_URL"] = mysql.url
+        mysql.configure()
 
     pg = Postgres(host, pg_port)
     pg.run_initdb()
@@ -220,17 +254,7 @@ def main():
     pg.configure()
     os.environ["PGPORT"] = str(pg_port)
 
-    skip_tests = [
-        "test_transform",
-        "TestLengthAtInsert",
-        "test_nullable",
-        "test_explicit_schema",
-        "test_insert_geom_poi",
-        "TestContraint",
-        "test_insert_geog_poi",
-        "TestInsertionCore",
-        "test_reflection_mysql",
-    ]
+    skip_tests = ["mysql"]
     if sys.byteorder == "big":
         # skip tests that fail when byteorder is big
         skip_tests += [
@@ -245,16 +269,18 @@ def main():
 
     ret = pytest.main(["-k", " and ".join(f"not {t}" for t in skip_tests)])
     pg.stop_server(pg_server)
-    mysql.stop_server()
-
+    assert pg_server.stderr
     pg_server_errors = pg_server.stderr.read()
     if ret:
         print("postgres server error log")
         print()
-        print(pg_server_errors.decode("utf-8"))
+        print(pg_server_errors)
 
     clean_up(pg.base_dir)
-    clean_up(mysql.base_dir)
+
+    if test_mysql:
+        mysql.stop_server()
+        clean_up(mysql.base_dir)
 
     return ret
 
